@@ -405,7 +405,7 @@ main (int argc, char** argv)
   } else {
 		  global_options.target_display = getenv ("DISPLAY");
 		  if (!global_options.target_display) {
-			  fprintf (stderr, _("Can't open display, DISPLAY is not set"));
+			  fprintf (stderr, _("Can't open display: DISPLAY is not set"));
 			  exit (1);
 		  }
   }  
