@@ -943,7 +943,20 @@ magnifier_set_property (BonoboPropertyBag *bag,
 			    gdk_display_get_screen (
 				magnifier->source_display,
 				magnifier->source_screen_num));
-	             /* attach listeners for DAMAGE, "dirty region", XFIXES cursor changes */
+
+		    /* remove the source_drawable, since in the new display the
+		     * composite can be unavailable and the source_drawable is
+		     * where the desktop screen is composed. If this is not
+		     * freed it will be used even if the display doesn't use
+		     * composite what will lead to wrong behavior and crashes.
+		     * If composite is used in the new display this variable is
+		     * re-created */
+		    if (magnifier->priv->source_drawable) {
+			    g_object_unref (magnifier->priv->source_drawable);
+			    magnifier->priv->source_drawable = NULL;
+		    }
+		    /* attach listeners for DAMAGE, "dirty region", XFIXES
+		     * cursor changes */
 	            magnifier_set_extension_listeners (magnifier, magnifier_get_root (magnifier));
 		    magnifier_get_display_rect_bounds (magnifier, &magnifier->source_bounds, FALSE);
 		    magnifier_zoom_regions_restore (magnifier, zoom_region_params);
@@ -1252,6 +1265,7 @@ impl_magnifier_create_zoom_region (PortableServer_Servant servant,
 	zoom_region->priv->parent = magnifier;
 
 	retval = BONOBO_OBJREF (zoom_region);
+
 	/* XXX: should check ev after each call, below */
 	CORBA_exception_init (ev);
 	GNOME_Magnifier_ZoomRegion_setMagFactor (retval, zx, zy, ev);
@@ -1670,8 +1684,8 @@ magnifier_new (gboolean override_redirect)
 		g_error ("Error registering magnifier server.\n");
 	}
 
-	g_idle_add (magnifier_reset_struts_at_idle, mag);
-	g_idle_add (gmag_gs_reset_overlay_at_idle, mag);
+	g_timeout_add (500, magnifier_reset_struts_at_idle, mag);
+	g_timeout_add (500, gmag_gs_reset_overlay_at_idle, mag);
 
 	return mag;
 }
